==> ome-common-cpp-5.2.0.tar.xz: ome-common-cpp-5.2.0/test/ome-common/units-temperature.cpp <==
/*
 * #%L
 * OME-COMMON C++ library for C++ compatibility/portability
 * %%
 * Copyright © 2015 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

#include "units.h"

#include <ome/common/units/temperature.h>

// Note lower precision is due to length of test data expected values.

typedef ::testing::Types<
  UnitConversion<celsius_absolute_quantity,    kelvin_absolute_quantity,     -10>,
  UnitConversion<kelvin_absolute_quantity,     celsius_absolute_quantity,    -10>,
  UnitConversion<fahrenheit_absolute_quantity, kelvin_absolute_quantity,      -5>,
  UnitConversion<kelvin_absolute_quantity,     fahrenheit_absolute_quantity, -10>,
  UnitConversion<rankine_absolute_quantity,    kelvin_absolute_quantity,      -5>,
  UnitConversion<kelvin_absolute_quantity,     rankine_absolute_quantity,    -10>,
  UnitConversion<celsius_absolute_quantity,    fahrenheit_absolute_quantity, -10>,
  UnitConversion<fahrenheit_absolute_quantity, celsius_absolute_quantity,     -3>
  > TemperatureTestTypes;

INSTANTIATE_TYPED_TEST_CASE_P(TemperatureTest, UnitConv, TemperatureTestTypes);

==> ome-common-cpp-5.4.0.tar.xz: ome-common-cpp-5.4.0/test/ome-common/units-temperature.cpp <==
/*
 * #%L
 * OME-COMMON C++ library for C++ compatibility/portability
 * %%
 * Copyright © 2015 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

#include "units.h"

#include <ome/common/units/temperature.h>

// Note lower precision is due to length of test data expected values.

typedef ::testing::Types<
  UnitConversion<celsius_absolute_quantity,    kelvin_absolute_quantity,     -10>,
  UnitConversion<kelvin_absolute_quantity,     celsius_absolute_quantity,    -10>,
  UnitConversion<fahrenheit_absolute_quantity, kelvin_absolute_quantity,      -5>,
  UnitConversion<kelvin_absolute_quantity,     fahrenheit_absolute_quantity, -10>,
  UnitConversion<rankine_absolute_quantity,    kelvin_absolute_quantity,      -5>,
  UnitConversion<kelvin_absolute_quantity,     rankine_absolute_quantity,    -10>,
  UnitConversion<celsius_absolute_quantity,    fahrenheit_absolute_quantity, -10>,
  UnitConversion<fahrenheit_absolute_quantity, celsius_absolute_quantity,     -3>,
  UnitConversion<rankine_absolute_quantity,    fahrenheit_absolute_quantity, -10>,
  UnitConversion<fahrenheit_absolute_quantity, rankine_absolute_quantity,    -10>,
  UnitConversion<rankine_absolute_quantity,    celsius_absolute_quantity,     -5>,
  UnitConversion<celsius_absolute_quantity,    rankine_absolute_quantity,    -10>
  > TemperatureTestTypes;

INSTANTIATE_TYPED_TEST_CASE_P(TemperatureTest, UnitConv, TemperatureTestTypes);
